# rubin-gafaelfawr

rubin-gafaelfawr is a client for [Gafaelfawr](https://gafaelfawr.lsst.io), which provides authentication and authorization for [Phalanx](https://phalanx.lsst.io/).
This package provides the Python client, Pydantic models, and a testing mock for applications that need to use the Gafaelfawr API directly.

rubin-gafaelfawr is available from [PyPI](https://pypi.org/project/rubin-gafaelfawr/):

```sh
pip install rubin-gafaelfawr
```

For full documentation, see [the Gafaelfawr user guide](https://gafaelfawr.lsst.io/user-guide/).
